package javax.swing.tree;

import java.awt.Rectangle;
import java.awt.Dimension;
import javax.swing.plaf.basic.BasicGraphicsUtils;
import java.awt.Graphics;
import java.awt.Component;
import javax.swing.plaf.ColorUIResource;
import javax.swing.plaf.FontUIResource;
import java.awt.Font;
import java.awt.Insets;
import javax.swing.border.EmptyBorder;
import javax.swing.UIManager;
import sun.swing.DefaultLookup;
import javax.swing.plaf.UIResource;
import javax.swing.Icon;
import java.awt.Color;
import javax.swing.JTree;
import javax.swing.JLabel;

public class DefaultTreeCellRenderer extends JLabel implements TreeCellRenderer
{
    private JTree tree;
    protected boolean selected;
    protected boolean hasFocus;
    private boolean drawsFocusBorderAroundIcon;
    private boolean drawDashedFocusIndicator;
    private Color treeBGColor;
    private Color focusBGColor;
    protected transient Icon closedIcon;
    protected transient Icon leafIcon;
    protected transient Icon openIcon;
    protected Color textSelectionColor;
    protected Color textNonSelectionColor;
    protected Color backgroundSelectionColor;
    protected Color backgroundNonSelectionColor;
    protected Color borderSelectionColor;
    private boolean isDropCell;
    private boolean fillBackground;
    private boolean inited;
    
    public DefaultTreeCellRenderer() {
        this.inited = true;
    }
    
    @Override
    public void updateUI() {
        super.updateUI();
        if (!this.inited || this.getLeafIcon() instanceof UIResource) {
            this.setLeafIcon(DefaultLookup.getIcon(this, this.ui, "Tree.leafIcon"));
        }
        if (!this.inited || this.getClosedIcon() instanceof UIResource) {
            this.setClosedIcon(DefaultLookup.getIcon(this, this.ui, "Tree.closedIcon"));
        }
        if (!this.inited || this.getOpenIcon() instanceof UIManager) {
            this.setOpenIcon(DefaultLookup.getIcon(this, this.ui, "Tree.openIcon"));
        }
        if (!this.inited || this.getTextSelectionColor() instanceof UIResource) {
            this.setTextSelectionColor(DefaultLookup.getColor(this, this.ui, "Tree.selectionForeground"));
        }
        if (!this.inited || this.getTextNonSelectionColor() instanceof UIResource) {
            this.setTextNonSelectionColor(DefaultLookup.getColor(this, this.ui, "Tree.textForeground"));
        }
        if (!this.inited || this.getBackgroundSelectionColor() instanceof UIResource) {
            this.setBackgroundSelectionColor(DefaultLookup.getColor(this, this.ui, "Tree.selectionBackground"));
        }
        if (!this.inited || this.getBackgroundNonSelectionColor() instanceof UIResource) {
            this.setBackgroundNonSelectionColor(DefaultLookup.getColor(this, this.ui, "Tree.textBackground"));
        }
        if (!this.inited || this.getBorderSelectionColor() instanceof UIResource) {
            this.setBorderSelectionColor(DefaultLookup.getColor(this, this.ui, "Tree.selectionBorderColor"));
        }
        this.drawsFocusBorderAroundIcon = DefaultLookup.getBoolean(this, this.ui, "Tree.drawsFocusBorderAroundIcon", false);
        this.drawDashedFocusIndicator = DefaultLookup.getBoolean(this, this.ui, "Tree.drawDashedFocusIndicator", false);
        this.fillBackground = DefaultLookup.getBoolean(this, this.ui, "Tree.rendererFillBackground", true);
        Insets insets = DefaultLookup.getInsets(this, this.ui, "Tree.rendererMargins");
        if (insets != null) {
            this.setBorder(new EmptyBorder(insets.top, insets.left, insets.bottom, insets.right));
        }
        this.setName("Tree.cellRenderer");
    }
    
    public Icon getDefaultOpenIcon() {
        return DefaultLookup.getIcon(this, this.ui, "Tree.openIcon");
    }
    
    public Icon getDefaultClosedIcon() {
        return DefaultLookup.getIcon(this, this.ui, "Tree.closedIcon");
    }
    
    public Icon getDefaultLeafIcon() {
        return DefaultLookup.getIcon(this, this.ui, "Tree.leafIcon");
    }
    
    public void setOpenIcon(Icon openIcon) {
        this.openIcon = openIcon;
    }
    
    public Icon getOpenIcon() {
        return this.openIcon;
    }
    
    public void setClosedIcon(Icon closedIcon) {
        this.closedIcon = closedIcon;
    }
    
    public Icon getClosedIcon() {
        return this.closedIcon;
    }
    
    public void setLeafIcon(Icon leafIcon) {
        this.leafIcon = leafIcon;
    }
    
    public Icon getLeafIcon() {
        return this.leafIcon;
    }
    
    public void setTextSelectionColor(Color textSelectionColor) {
        this.textSelectionColor = textSelectionColor;
    }
    
    public Color getTextSelectionColor() {
        return this.textSelectionColor;
    }
    
    public void setTextNonSelectionColor(Color textNonSelectionColor) {
        this.textNonSelectionColor = textNonSelectionColor;
    }
    
    public Color getTextNonSelectionColor() {
        return this.textNonSelectionColor;
    }
    
    public void setBackgroundSelectionColor(Color backgroundSelectionColor) {
        this.backgroundSelectionColor = backgroundSelectionColor;
    }
    
    public Color getBackgroundSelectionColor() {
        return this.backgroundSelectionColor;
    }
    
    public void setBackgroundNonSelectionColor(Color backgroundNonSelectionColor) {
        this.backgroundNonSelectionColor = backgroundNonSelectionColor;
    }
    
    public Color getBackgroundNonSelectionColor() {
        return this.backgroundNonSelectionColor;
    }
    
    public void setBorderSelectionColor(Color borderSelectionColor) {
        this.borderSelectionColor = borderSelectionColor;
    }
    
    public Color getBorderSelectionColor() {
        return this.borderSelectionColor;
    }
    
    @Override
    public void setFont(Font font) {
        if ((font instanceof FontUIResource)) {
            font = null;
        }
        super.setFont(font);
    }
    
    @Override
    public Font getFont() {
        Font font = super.getFont();
        if (font == null && this.tree != null) {
            font = this.tree.getFont();
            return font;
        }
        return font;
    }
    
    @Override
    public void setBackground(Color background) {
        if ((background instanceof ColorUIResource)) {
            background = null;
        }
        super.setBackground(background);
    }
    
    @Override
    public Component getTreeCellRendererComponent(JTree tree, Object value, boolean b, boolean expanded, boolean leaf, int row, boolean b2) {
        String convertValueToText = tree.convertValueToText(value, b, expanded, leaf, row, b2);
        this.tree = tree;
        this.hasFocus = b2;
        this.setText(convertValueToText);
        this.isDropCell = false;
        JTree.DropLocation dropLocation = tree.getDropLocation();
        Color foreground;
        if (dropLocation != null && dropLocation.getChildIndex() == -1 && tree.getRowForPath(dropLocation.getPath()) == row) {
            Color color = DefaultLookup.getColor(this, this.ui, "Tree.dropCellForeground");
            if (color != null) {
                foreground = color;
            }
            else {
                foreground = this.getTextSelectionColor();
            }
            this.isDropCell = true;
        }
        else if (b) {
            foreground = this.getTextSelectionColor();
        }
        else {
            foreground = this.getTextNonSelectionColor();
        }
        this.setForeground(foreground);
        Icon disabledIcon;
        if (leaf) {
            disabledIcon = this.getLeafIcon();
        }
        else if (expanded) {
            disabledIcon = this.getOpenIcon();
        }
        else {
            disabledIcon = this.getClosedIcon();
        }
        if (!tree.isEnabled()) {
            this.setEnabled(false);
            Icon disabledIcon2 = UIManager.getLookAndFeel().getDisabledIcon(tree, disabledIcon);
            if (disabledIcon2 != null) {
                disabledIcon = disabledIcon2;
            }
            this.setDisabledIcon(disabledIcon);
        }
        else {
            this.setEnabled(true);
            this.setIcon(disabledIcon);
        }
        this.setComponentOrientation(tree.getComponentOrientation());
        this.selected = b;
        return this;
    }
    
    @Override
    public void paint(Graphics g) {
        Color color;
        if (this.isDropCell) {
            color = DefaultLookup.getColor(this, this.ui, "Tree.dropCellBackground");
            if (color == null) {
                color = this.getBackgroundSelectionColor();
            }
        }
        else if (this.selected) {
            color = this.getBackgroundSelectionColor();
        }
        else {
            color = this.getBackgroundNonSelectionColor();
            if (color == null) {
                color = this.getBackground();
            }
        }
        int n = -1;
        if (color != null && this.fillBackground) {
            n = this.getLabelStart();
            g.setColor(color);
            if (this.getComponentOrientation().isLeftToRight()) {
                g.fillRect(n, 0, this.getWidth() - n, this.getHeight());
            }
            else {
                g.fillRect(0, 0, this.getWidth() - n, this.getHeight());
            }
        }
        if (this.hasFocus) {
            if (this.drawsFocusBorderAroundIcon) {
                n = 0;
            }
            else if (n == -1) {
                n = this.getLabelStart();
            }
            if (this.getComponentOrientation().isLeftToRight()) {
                this.paintFocus(g, n, 0, this.getWidth() - n, this.getHeight(), color);
            }
            else {
                this.paintFocus(g, 0, 0, this.getWidth() - n, this.getHeight(), color);
            }
        }
        super.paint(g);
    }
    
    private void paintFocus(Graphics g, int n, int n2, int width, int height, Color treeBGColor) {
        Color borderSelectionColor = this.getBorderSelectionColor();
        if (borderSelectionColor != null && (this.selected || !this.drawDashedFocusIndicator)) {
            g.setColor(borderSelectionColor);
            g.drawRect(n, n2, width - 1, height - 1);
        }
        if (this.drawDashedFocusIndicator && treeBGColor != null) {
            if (this.treeBGColor != treeBGColor) {
                this.treeBGColor = treeBGColor;
                this.focusBGColor = new Color(~treeBGColor.getRGB());
            }
            g.setColor(this.focusBGColor);
            BasicGraphicsUtils.drawDashedRect(g, n, n2, width, height);
        }
    }
    
    private int getLabelStart() {
        Icon icon = this.getIcon();
        if (icon != null && this.getText() != null) {
            return icon.getIconWidth() + Math.max(0, this.getIconTextGap() - 1);
        }
        return 0;
    }
    
    @Override
    public Dimension getPreferredSize() {
        Dimension preferredSize = super.getPreferredSize();
        if (preferredSize != null) {
            preferredSize = new Dimension(preferredSize.width + 3, preferredSize.height);
            return preferredSize;
        }
        return preferredSize;
    }
    
    @Override
    public void validate() {
    }
    
    @Override
    public void invalidate() {
    }
    
    @Override
    public void revalidate() {
    }
    
    @Override
    public void repaint(long n, int n2, int n3, int n4, int n5) {
    }
    
    @Override
    public void repaint(Rectangle rectangle) {
    }
    
    @Override
    public void repaint() {
    }
    
    @Override
    protected void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
        if (propertyName == "text" || ((propertyName == "font" || propertyName == "foreground") && oldValue != newValue && this.getClientProperty("html") != null)) {
            super.firePropertyChange(propertyName, oldValue, newValue);
        }
    }
    
    @Override
    public void firePropertyChange(String s, byte b, byte b2) {
    }
    
    @Override
    public void firePropertyChange(String s, char c, char c2) {
    }
    
    @Override
    public void firePropertyChange(String s, short n, short n2) {
    }
    
    @Override
    public void firePropertyChange(String s, int n, int n2) {
    }
    
    @Override
    public void firePropertyChange(String s, long n, long n2) {
    }
    
    @Override
    public void firePropertyChange(String s, float n, float n2) {
    }
    
    @Override
    public void firePropertyChange(String s, double n, double n2) {
    }
    
    @Override
    public void firePropertyChange(String s, boolean b, boolean b2) {
    }
}
